pub struct EnterArgs {Show 14 fields
environment: Environment,
url: Option<Url>,
wait_for_card: bool,
chained_session_drip: bool,
confirm: bool,
card_comment: Option<String>,
hub_handle: Option<Handle>,
local_client: bool,
local_client_url: Url,
auth_token: Option<AuthToken>,
id_attr_type: HandleChoice,
add_attr_type: Vec<Handle>,
dont_add_attrs: bool,
register_only_with_unique_attrs: bool,
}Fields
environment: EnvironmentEnter this pubhubs environment
url: Option<Url>Contact PHC at this url, overriding –environment
wait_for_card: boolWhether to wait for a pubhubs yivi card
chained_session_drip: boolWhether to use ‘chained session drip’, AuthStartReq::yivi_chained_session_drip
confirm: boolAsk for confirmation before proceeding at certain points. Useful for letting something time out.
card_comment: Option<String>Comment to use on the pubhubs card, provided a card is requested
hub_handle: Option<Handle>Handle identifying the hub
local_client: boolInstead of the displaying the actual client url after entering a hub, display the local client url. Useful when running your local client against main.
local_client_url: UrlThe local client url used by –local-client.
auth_token: Option<AuthToken>Use this pubhubs authentication token
id_attr_type: HandleChoiceIdentifying attribute type to use
add_attr_type: Vec<Handle>Add these attributes when entering pubhubs
dont_add_attrs: boolDon’t add any attributes when entering pubhubs
register_only_with_unique_attrs: boolDon’t create a new account if one of the supplied attributes already bans another account
Implementations
Sourceimpl EnterArgs
impl EnterArgs
pub fn run(self, _spec: &mut Command) -> Result<()>
fn url(&self) -> Cow<'_, Url>
async fn confirm(&self, msg: &str)
async fn run_async(self) -> Result<()>
Sourceasync fn get_auth_token(
&self,
client: &Client,
constellation: &Constellation,
attr_types: &HashMap<Handle, Type>,
) -> Result<AuthToken>
async fn get_auth_token( &self, client: &Client, constellation: &Constellation, attr_types: &HashMap<Handle, Type>, ) -> Result<AuthToken>
Enter pubhubs using a QR code on the command line; returns an auth token.